__all__ = (
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
)

__title__ = "ezpp"
__summary__ = "Easy Pic Process"
__uri__ = "https://github.com/caojianfeng/ezpp"

__version__ = "1.0.0"

__author__ = "JeffreyCao"
__email__ = "je255reycao@stufft.io"

__license__ = "MIT Licence"
__copyright__ = "Copyright 2019 JeffreyCao"
